<img src="https://github.com/barel-mishal/incal_lib/blob/main/photos/logo.png?raw=true" width="500" height="257.2">

## InCal_lib rapid advence analysis for indirect calorimetry expriment data

InCal (INdirect CALorimetry) is a Python package for rapid analysis of indirect calorimetry experiments. InCAL help biologist uses the python language to analyze their experiment and get their insight fest.
InCal's goal is to provide open-source tools for metabolic labs that use indirect calorimetry devices.

### Usage:

### Installation:

pip - package menager:

```
$ pip install InCal_lib
```

package menager - package menager:
If using anaconda package menager please follow this tutorial and use pip also.
https://stackoverflow.com/questions/41060382/using-pip-to-install-packages-to-anaconda-environment

## Licence

MIT LISENCE - [LICENSE](https://github.com/barel-mishal/incal_lib/blob/main/LICENSE).

## Contact

## API:

### READ:

FUNCTION: read_sable_calr_csv()

### MARKS TO GROUPBY:

link: custom_days()
